Learn R Programming

mevr (version 1.1.1)

censored_weibull_fit: Fit Weibull distribution to censored data

Description

Finds the optimal left-censoring threshold(s) at which the data series should be censored to make sure that the observations in the tail are likely sampled from a Weibull distribution

Usage

censored_weibull_fit(x, thresholds)

Value

A tibble with the optimal threshold itself and the Weibull scale and shape parameters obtained from the censored sample.

Arguments

x

A tibble which is most commonly a result of function weibull_tail_test.

thresholds

A numeric or vector of quantiles which shal be tested as optimal threshold for left-censoring.

Examples

Run this code
data("dailyrainfall")
wbtest <- weibull_tail_test(dailyrainfall)
censored_weibull_fit(wbtest, 0.9)

Run the code above in your browser using DataLab