Learn R Programming

mevr (version 1.1.1)

dtmev: The non-stationary Metastatistical Extreme Value Distribution

Description

Quantile function for the TMEV distribution with a Weibull parent distribution.

Usage

dtmev(x, data)

ptmev(q, data)

qtmev(p, data)

Value

dtmev gives the density function, ptmev gives the distribution function, and qtmev gives the quantile function of the TMEV.

Arguments

x, q

Numeric vector or single value of probabilities for dtmev.

data

A data frame with at least columns c, w and year. Can be taken from the output of the fitted TMEV object, i.e. x$data (see ftmev).

p

Numeric vector or single value of probabilities for qtmev.

Functions

  • ptmev(): distribution quantile function

  • qtmev(): distribution quantile function

Examples

Run this code
data(dailyrainfall)
fit <- ftmev(dailyrainfall)
rp <- pp.weibull(fit$maxima)
rl <- qtmev(1 - 1 / rp, fit$data)
plot(rp, sort(fit$maxima), main = "TMEV", ylab = "return level", xlab = "return period (years)")
lines(rp, rl, type = "l")


Run the code above in your browser using DataLab